@@ -49,6 +49,7 @@ static struct v2_0_config v2_0_config_elements[] = {
 	{"check_options",		STATS_OFFSET(check_options),		VARTYPE_INT},
 	{"check_period",		STATS_OFFSET(check_period),		VARTYPE_PCHAR},
 	{"check_type",			STATS_OFFSET(check_type),		VARTYPE_INT}, 
+	{"comment",			STATS_OFFSET(comment),			VARTYPE_PCHAR},
 	{"comment_data",		STATS_OFFSET(comment_data),		VARTYPE_PCHAR},
 	{"comment_id",			STATS_OFFSET(comment_id),		VARTYPE_INT},
 	{"current_attempt",		STATS_OFFSET(current_attempt),		VARTYPE_INT}, 
@@ -57,6 +58,9 @@ static struct v2_0_config v2_0_config_elements[] = {
 	{"current_notification_number",	STATS_OFFSET(current_notification_number),	VARTYPE_DOUBLE}, 
 	{"current_problem_id",		STATS_OFFSET(current_problem_id),	VARTYPE_INT},
 	{"current_state",		STATS_OFFSET(current_state),		VARTYPE_INT}, 
+	{"downtime_id",			STATS_OFFSET(downtime_id),		VARTYPE_INT},
+	{"duration",			STATS_OFFSET(duration),			VARTYPE_INT},
+	{"end_time",			STATS_OFFSET(end_time),			VARTYPE_TIMET},
 	{"entry_time",			STATS_OFFSET(entry_time),		VARTYPE_TIMET},
 	{"entry_type",			STATS_OFFSET(entry_type),		VARTYPE_INT},
 	{"event_handler",		STATS_OFFSET(event_handler),		VARTYPE_INT}, 
@@ -64,6 +68,7 @@ static struct v2_0_config v2_0_config_elements[] = {
 	{"expire_time",			STATS_OFFSET(expire_time),		VARTYPE_TIMET},
 	{"expires",			STATS_OFFSET(expires),			VARTYPE_INT},
 	{"failure_prediction_enabled",	STATS_OFFSET(failure_prediction_enabled),	VARTYPE_INT}, 
+	{"fixed",			STATS_OFFSET(fixed),			VARTYPE_INT},
 	{"flap_detection_enabled",	STATS_OFFSET(flap_detection_enabled),	VARTYPE_INT}, 
 	{"has_been_checked",		STATS_OFFSET(has_been_checked),		VARTYPE_INT}, 
 	{"host_name",			STATS_OFFSET(host_name),		VARTYPE_PCHAR}, 
@@ -75,7 +80,6 @@ static struct v2_0_config v2_0_config_elements[] = {
 	{"last_hard_state_change",	STATS_OFFSET(last_hard_state_change),	VARTYPE_INT}, 
 	{"last_notification",		STATS_OFFSET(last_notification),	VARTYPE_INT}, 
 	{"last_problem_id",		STATS_OFFSET(last_problem_id),		VARTYPE_INT},
-	{"long_plugin_output",		STATS_OFFSET(long_plugin_output),	VARTYPE_PCHAR},
 	{"last_state_change",		STATS_OFFSET(last_state_change),	VARTYPE_TIMET}, 
 	{"last_time_critical",		STATS_OFFSET(last_time_critical),	VARTYPE_INT}, 
 	{"last_time_down",		STATS_OFFSET(last_time_down),		VARTYPE_INT}, 
@@ -108,7 +112,9 @@ static struct v2_0_config v2_0_config_elements[] = {
 	{"service_description",		STATS_OFFSET(service_description),	VARTYPE_PCHAR}, 
 	{"should_be_scheduled",		STATS_OFFSET(should_be_scheduled),	VARTYPE_INT}, 
 	{"source",			STATS_OFFSET(source),			VARTYPE_INT},
+	{"start_time",			STATS_OFFSET(start_time),		VARTYPE_TIMET},
 	{"state_type",			STATS_OFFSET(state_type),		VARTYPE_INT}, 
+	{"triggered_by",		STATS_OFFSET(triggered_by),		VARTYPE_INT},
 	{"type",			STATS_OFFSET(type),			VARTYPE_INT}
 };
 
@@ -266,7 +272,7 @@ void parse_2_0_statuslog(int fd, struct stats **pstats, int *n_stats)
 			}
 
 
-			if (strncmp(line, "host ", 5) == 0)
+			if (strncmp(line, "host", 4) == 0)
 			{
 				type = TYPE_HOST;
 			}
@@ -662,7 +668,14 @@ void free_stats_array(struct stats *pstats, int n_stats)
 			myfree(pstats[loop].service_description, "entry servicedescription");
 			myfree(pstats[loop].plugin_output, "entry plugin output");
 			myfree(pstats[loop].performance_data, "entry performance data");
-			myfree(pstats[loop].check_command, "check command");
+			myfree(pstats[loop].check_command, "entry check command");
+			myfree(pstats[loop].author, "entry author");
+			myfree(pstats[loop].check_period, "entry check_period");
+			myfree(pstats[loop].comment_data, "entry comment data");
+			myfree(pstats[loop].host_notification_period, "entry host notification period");
+			myfree(pstats[loop].long_plugin_output, "entry long plugin output");
+			myfree(pstats[loop].notification_period, "entry notification period");
+			myfree(pstats[loop].service_notification_period, "entry service notification period");
 		}
 
 		myfree(pstats, "stats array");
@@ -812,15 +825,6 @@ int check_max_age_last_check(struct stats *pstats, int n_stats, int max_time_las
 
 	for(index=0; index<n_stats; index++)
 	{
-		if (pstats[index].active_checks_enabled == 0)
-			continue;
-
-		if (pstats[index].scheduled_downtime_depth != 0)
-			continue;
-
-		if (pstats[index].notifications_enabled == 0)
-			continue;
-
 		if (pstats[index].type == TYPE_HOST)
 		{
 			if (pstats[index].last_update != 0)
@@ -835,8 +839,8 @@ int check_max_age_last_check(struct stats *pstats, int n_stats, int max_time_las
 			{
 				most_recent_host_check = max(most_recent_host_check, pstats[index].last_check);
 
-				//				if (check_an_age(message, "oldest host check", now, pstats[index].last_check, max_time_oldest_host_check, pstats[index].host_name) == -1)
-				//					return -1;
+				// if (check_an_age(message, "oldest host check", now, pstats[index].last_check, max_time_oldest_host_check, pstats[index].host_name) == -1)
+				//	return -1;
 			}
 		}
 		else if (pstats[index].type == TYPE_SERVICE)
@@ -863,8 +867,8 @@ int check_max_age_last_check(struct stats *pstats, int n_stats, int max_time_las
 	if (check_an_age(message, "most recent host update", now, most_recent_host_update, max_time_last_host_update, NULL) == -1)
 		return -1;
 
-	//	if (check_an_age(message, "most recent host check", now, most_recent_host_check, max_time_last_host_check, NULL) == -1)
-	//		return -1;
+	// if (check_an_age(message, "most recent host check", now, most_recent_host_check, max_time_last_host_check, NULL) == -1)
+	//	return -1;
 
 	if (check_an_age(message, "most recent last service check", now, most_recent_last_service_check, max_time_last_service_check, NULL) == -1)
 		return -1;
