@@ -114,6 +114,12 @@ struct stats
 	double retry_interval;
 	char *service_notification_period;
 	int source;
+	int downtime_id;
+	time_t start_time, end_time;
+	int triggered_by;
+	int fixed;
+	int duration;
+	char *comment;
 };
 
 void parse_1_0_statuslog(int fd, struct stats **pstats, int *n_stats);
